@@ -1,6 +1,7 @@
 from snitch_ai.internal.guid import GUID
 from snitch_ai.internal.api_client import ApiClient
 from snitch_ai.internal.analysis_status import AnalysisState, AnalysisStatus
+from snitch_ai.internal.logger import Logger
 
 class DriftAnalysis:
 
@@ -29,6 +30,8 @@ class DriftAnalysis:
         Gets the JSON results for this Drift analysis.
         :return: The JSON results.
         """
+        Logger.information("Fetching JSON results...")
+
         client = ApiClient()
         resp = client.get(f"project/{self.project_id}/drift/{self.drift_id}/json")
         if resp.status_code != 200:
@@ -42,6 +45,8 @@ class DriftAnalysis:
         Saves the PDF report of this Drift analysis to the specified path.
         :param path: The path to save the PDF report to.
         """
+        Logger.information("Fetching PDF report...")
+
         client = ApiClient()
         resp = client.get(f"project/{self.project_id}/drift/{self.drift_id}/pdf")
         if resp.status_code != 200:
