@@ -12,6 +12,7 @@ from requests.exceptions import ConnectionError
 
 from snitch_ai.internal.guid import GUID
 from snitch_ai.internal.api_client import ApiClient
+from snitch_ai.internal.logger import Logger
 from snitch_ai.internal.quality_analysis import QualityAnalysis
 from snitch_ai.internal.drift_analysis import DriftAnalysis
 from snitch_ai.internal.analysis_status import AnalysisState
@@ -57,6 +58,7 @@ def _save_dataset_to_path(dataset, path):
 
 
 def _upload_quality_analysis_file(project_id, quality_id, client, file_name, file_path):
+    Logger.information(f"Sending file '{file_name}' to Snitch Agent...")
     with open(file_path, "rb") as f:
         data = _prepare_multipart_file_upload(f, file_name, file_path)
         try:
@@ -67,11 +69,14 @@ def _upload_quality_analysis_file(project_id, quality_id, client, file_name, fil
             else:
                 raise Exception("Error while uploading files to remote host. Please try again later.");
 
+        Logger.information(f"File '{file_name}' sent to Snitch Agent!")
+
         if resp.status_code != 200:
             raise Exception(f"Error uploading file: {resp.text}")
 
 
 def _upload_drift_analysis_file(project_id, drift_id, client, file_name, file_path):
+    Logger.information(f"Sending file '{file_name}' to Snitch Agent...")
     with open(file_path, "rb") as f:
         data = _prepare_multipart_file_upload(f, file_name, file_path)
         try: 
@@ -82,6 +87,8 @@ def _upload_drift_analysis_file(project_id, drift_id, client, file_name, file_pa
             else:
                 raise Exception("Error while uploading files to remote host. Please try again later.");
 
+        Logger.information(f"File '{file_name}' sent to Snitch Agent!")
+
         if resp.status_code != 200:
             raise Exception(f"Error uploading file: {resp.text}")
 
@@ -100,18 +107,23 @@ def _prepare_multipart_file_upload(file_handle, file_name, file_path) -> Multipa
 
 def _wait_on_analysis_completion(analysis: Union[QualityAnalysis, DriftAnalysis]):
     # wait for analysis to complete
+    elapsed = 0
     count = 1
     waiting_on_completion = True
     while waiting_on_completion:
         # wait for 2, 4, 8, 16, 32, 32, 32, ... seconds before re-checking
         delay = math.pow(2, min(count, 5))
-        count += 1
         time.sleep(delay)
+        elapsed += delay
+        count += 1
+
+        Logger.information(f"Analysis running. Waiting for status update... ({str(datetime.timedelta(seconds=elapsed))} elapsed)")
 
         status = analysis.get_status()
 
         if status.state == AnalysisState.COMPLETED:
             waiting_on_completion = False
+            Logger.information("Analysis completed!")
         elif status.state == AnalysisState.ERROR:
             raise Exception(f"The analysis failed due to an error: {status.error}")
         elif status.state == AnalysisState.UNKNOWN:
@@ -177,6 +189,8 @@ class Project:
         quality_obj = resp.json()
         quality_id = quality_obj["id"]
 
+        Logger.information(f"Created quality analysis '{label}' (ID: '{quality_id}').")  
+
         # upload files
         temp_dir = tempfile.mkdtemp(prefix="snitch_ai_")
         try:
@@ -213,10 +227,14 @@ class Project:
             shutil.rmtree(temp_dir)
 
         # start analysis
+        Logger.information("Starting quality analysis...")
+
         resp = client.post(f"project/{self.project_id}/quality/{quality_id}/start")
         if resp.status_code != 200:
             raise Exception(f"Error starting quality analysis: {resp.text}")
 
+        Logger.information("Started quality analysis!")
+
         quality_analysis = QualityAnalysis(self.project_id, quality_id)
 
         if not no_wait:
@@ -266,6 +284,8 @@ class Project:
         drift_obj = resp.json()
         drift_id = drift_obj["id"]
 
+        Logger.information(f"Created drift analysis '{label}' (ID: '{drift_id}').")  
+
         # upload files
         temp_dir = tempfile.mkdtemp(prefix="snitch_ai_")
         try:
@@ -286,7 +306,12 @@ class Project:
             shutil.rmtree(temp_dir)
 
         # start analysis
+        Logger.information("Starting drift analysis...")
+
         resp = client.post(f"project/{self.project_id}/drift/{drift_id}/start")
+
+        Logger.information("Started drift analysis!")
+
         if resp.status_code != 200:
             raise Exception(f"Error starting drift analysis: {resp.text}")
 
@@ -313,6 +338,8 @@ def select_project(project_name: str) -> Project:
     if resp.status_code != 200 and resp.status_code != 201:
         raise Exception(f"Could not select project: {resp.text}")
 
+    Logger.information(f"Selected project: {project_name}")
+
     json = resp.json()
 
     return Project(GUID(json["id"]), json["name"])
@@ -330,6 +357,8 @@ def create_project(project_name: str) -> Project:
     if resp.status_code != 201:
         raise Exception(f"Could not create project: {resp.text}")
 
+    Logger.information(f"Created project: {project_name}")
+
     json = resp.json()
 
     return Project(GUID(json["id"]), json["name"])
